options(testthat.progress.max_fails = 100)
library(testthat)
library(greta)
test_check("greta")
